import 'dart:async';

import 'package:flutter/material.dart';
import 'package:google_maps_flutter/google_maps_flutter.dart';

class MapOfCoordinateWidget extends StatefulWidget {
  final String latitude;
  final String longitude;
  const MapOfCoordinateWidget({
    super.key,
    required this.latitude,
    required this.longitude,
  });

  @override
  State<MapOfCoordinateWidget> createState() => _MapOfCoordinateWidgetState();
}

class _MapOfCoordinateWidgetState extends State<MapOfCoordinateWidget> {
  final Completer<GoogleMapController> mapController =
      Completer<GoogleMapController>();

  void onMapCreated(GoogleMapController controller) {
    mapController.complete(controller);
  }

  BitmapDescriptor markerIcon = BitmapDescriptor.defaultMarker;

  final Set<Marker> markers = <Marker>{};

  void addCustomIcon() {
    BitmapDescriptor.fromAssetImage(
      const ImageConfiguration(),
      "assets/images/map-pin.png",
    ).then(
      (icon) {
        setState(() {
          markerIcon = icon;
        });
      },
    );
  }

  @override
  void initState() {
    super.initState();
    addCustomIcon();
  }

  @override
  Widget build(BuildContext context) {
    final position = LatLng(
      double.parse(widget.latitude),
      double.parse(widget.longitude),
    );

    return SizedBox(
      height: 300,
      child: GoogleMap(
        markers: {
          Marker(
            markerId: MarkerId(position.toString()),
            position: position,
            icon: markerIcon,
          )
        },
        mapType: MapType.normal,
        myLocationEnabled: false,
        initialCameraPosition: CameraPosition(
          target: position,
          zoom: 15,
        ),
        onMapCreated: onMapCreated,
      ),
    );
  }
}
